@@ -24,7 +24,9 @@ from typing import (
 # project
 import kiwi.defaults as defaults
 
+from kiwi.utils.veritysetup import VeritySetup
 from kiwi.utils.temporary import Temporary
+from kiwi.system.mount import ImageSystem
 from kiwi.storage.disk import ptable_entry_type
 from kiwi.defaults import Defaults
 from kiwi.filesystem.base import FileSystemBase
@@ -91,6 +93,14 @@ class DiskBuilder:
         self.root_filesystem_is_overlay = xml_state.build_type.get_overlayroot()
         self.root_filesystem_has_write_partition = \
             xml_state.build_type.get_overlayroot_write_partition()
+        self.root_filesystem_read_only_partsize = \
+            xml_state.build_type.get_overlayroot_readonly_partsize()
+        self.root_filesystem_verity_blocks = \
+            xml_state.build_type.get_verity_blocks()
+        self.root_filesystem_embed_verity_metadata = \
+            xml_state.build_type.get_embed_verity_metadata()
+        self.dosparttable_extended_layout = \
+            xml_state.build_type.get_dosparttable_extended_layout()
         self.custom_root_mount_args = xml_state.get_fs_mount_option_list()
         self.custom_root_creation_args = xml_state.get_fs_create_option_list()
         self.build_type_name = xml_state.get_build_type_name()
@@ -106,7 +116,8 @@ class DiskBuilder:
         self.mdraid = xml_state.build_type.get_mdraid()
         self.hybrid_mbr = xml_state.build_type.get_gpt_hybrid_mbr()
         self.force_mbr = xml_state.build_type.get_force_mbr()
-        self.luks = xml_state.build_type.get_luks()
+        self.luks = xml_state.get_luks_credentials()
+        self.luks_format_options = xml_state.get_luks_format_options()
         self.luks_os = xml_state.build_type.get_luksOS()
         self.xen_server = xml_state.is_xen_server()
         self.requested_filesystem = xml_state.build_type.get_filesystem()
@@ -248,7 +259,8 @@ class DiskBuilder:
 
         disk = Disk(
             self.firmware.get_partition_table_type(), loop_provider,
-            self.xml_state.get_disk_start_sector()
+            self.xml_state.get_disk_start_sector(),
+            extended_layout=bool(self.dosparttable_extended_layout)
         )
 
         # create the bootloader instance
@@ -311,6 +323,7 @@ class DiskBuilder:
             luks_root.create_crypto_luks(
                 passphrase=self.luks,
                 os=self.luks_os,
+                options=self.luks_format_options,
                 keyfile=self.luks_boot_keyfile if luks_need_keyfile else ''
             )
             if luks_need_keyfile:
@@ -376,23 +389,25 @@ class DiskBuilder:
             device_map['root'] = volume_manager.get_device().get('root')
             device_map['swap'] = volume_manager.get_device().get('swap')
         else:
-            log.info(
-                'Creating root(%s) filesystem on %s',
-                self.requested_filesystem, device_map['root'].get_device()
-            )
-            filesystem_custom_parameters = {
-                'mount_options': self.custom_root_mount_args,
-                'create_options': self.custom_root_creation_args
-            }
-            filesystem = FileSystem.new(
-                self.requested_filesystem, device_map['root'],
-                self.root_dir + '/',
-                filesystem_custom_parameters
-            )
-            filesystem.create_on_device(
-                label=self.disk_setup.get_root_label()
-            )
-            system = filesystem
+            if not self.root_filesystem_is_overlay or \
+               self.root_filesystem_has_write_partition is not False:
+                log.info(
+                    'Creating root(%s) filesystem on %s',
+                    self.requested_filesystem, device_map['root'].get_device()
+                )
+                filesystem_custom_parameters = {
+                    'mount_options': self.custom_root_mount_args,
+                    'create_options': self.custom_root_creation_args
+                }
+                filesystem = FileSystem.new(
+                    self.requested_filesystem, device_map['root'],
+                    self.root_dir + '/',
+                    filesystem_custom_parameters
+                )
+                filesystem.create_on_device(
+                    label=self.disk_setup.get_root_label()
+                )
+                system = filesystem
 
         # create swap on current root device if requested
         if self.swap_mbytes:
@@ -477,12 +492,18 @@ class DiskBuilder:
         if self.system_setup.script_exists(
             defaults.POST_DISK_SYNC_SCRIPT
         ):
-            disk_system = SystemSetup(
-                self.xml_state, system.get_mountpoint()
+            image_system = ImageSystem(
+                device_map, self.root_dir,
+                system.get_volumes() if self.volume_manager_name else {}
             )
-            disk_system.import_description()
-            disk_system.call_disk_script()
-            disk_system.cleanup()
+            image_system.mount()
+            disk_system = SystemSetup(
+                self.xml_state, image_system.mountpoint()
+            )
+            try:
+                disk_system.call_disk_script()
+            finally:
+                image_system.umount()
 
         # install boot loader
         self._install_bootloader(device_map, disk, system)
@@ -663,7 +684,8 @@ class DiskBuilder:
             exclude_list.append('boot/efi/.*')
         if self.custom_partitions:
             for map_name in sorted(self.custom_partitions.keys()):
-                if map_name in device_map:
+                if map_name in device_map and \
+                   self.custom_partitions[map_name].mountpoint:
                     mountpoint = os.path.normpath(
                         self.custom_partitions[map_name].mountpoint
                     ).lstrip(os.sep)
@@ -684,15 +706,16 @@ class DiskBuilder:
             for map_name in sorted(custom_partitions.keys()):
                 if map_name in device_map:
                     ptable_entry = custom_partitions[map_name]
-                    filesystem = FileSystem.new(
-                        ptable_entry.filesystem,
-                        device_map[map_name],
-                        f'{self.root_dir}{ptable_entry.mountpoint}/'
-                    )
-                    filesystem.create_on_device(
-                        label=map_name.upper()
-                    )
-                    filesystem_list.append(filesystem)
+                    if ptable_entry.filesystem:
+                        filesystem = FileSystem.new(
+                            ptable_entry.filesystem,
+                            device_map[map_name],
+                            f'{self.root_dir}{ptable_entry.mountpoint}/'
+                        )
+                        filesystem.create_on_device(
+                            label=map_name.upper()
+                        )
+                        filesystem_list.append(filesystem)
         return filesystem_list
 
     def _build_spare_filesystem(self, device_map: Dict) -> Optional[FileSystemBase]:
@@ -817,21 +840,23 @@ class DiskBuilder:
 
         if self.root_filesystem_is_overlay:
             log.info('--> creating readonly root partition')
-            squashed_root_file = Temporary().new_file()
-            squashed_root = FileSystemSquashFs(
-                device_provider=DeviceProvider(), root_dir=self.root_dir,
-                custom_args={
-                    'compression':
-                        self.xml_state.build_type.get_squashfscompression()
-                }
-            )
-            squashed_root.create_on_file(
-                filename=squashed_root_file.name,
-                exclude=[Defaults.get_shared_cache_location()]
-            )
-            squashed_rootfs_mbsize = int(
-                os.path.getsize(squashed_root_file.name) / 1048576
-            ) + Defaults.get_min_partition_mbytes()
+            squashed_rootfs_mbsize = self.root_filesystem_read_only_partsize
+            if not self.root_filesystem_read_only_partsize:
+                squashed_root_file = Temporary().new_file()
+                squashed_root = FileSystemSquashFs(
+                    device_provider=DeviceProvider(), root_dir=self.root_dir,
+                    custom_args={
+                        'compression':
+                            self.xml_state.build_type.get_squashfscompression()
+                    }
+                )
+                squashed_root.create_on_file(
+                    filename=squashed_root_file.name,
+                    exclude=[Defaults.get_shared_cache_location()]
+                )
+                squashed_rootfs_mbsize = int(
+                    os.path.getsize(squashed_root_file.name) / 1048576
+                ) + Defaults.get_min_partition_mbytes()
             disk.create_root_readonly_partition(
                 squashed_rootfs_mbsize
             )
@@ -989,7 +1014,8 @@ class DiskBuilder:
             )
         if self.custom_partitions:
             for map_name in sorted(self.custom_partitions.keys()):
-                if device_map.get(map_name):
+                if device_map.get(map_name) and \
+                   self.custom_partitions[map_name].mountpoint:
                     self._add_fstab_entry(
                         device_map[map_name].get_device(),
                         self.custom_partitions[map_name].mountpoint
@@ -1014,8 +1040,12 @@ class DiskBuilder:
                 ]
             )
         else:
-            blkid_type = 'LABEL' if self.persistency_type == 'by-label' \
-                else 'UUID'
+            if self.persistency_type == 'by-label':
+                blkid_type = 'LABEL'
+            elif self.persistency_type == 'by-partuuid':
+                blkid_type = 'PARTUUID'
+            else:
+                blkid_type = 'UUID'
             device_id = block_operation.get_blkid(blkid_type)
             fstab_entry = ' '.join(
                 [
@@ -1152,17 +1182,103 @@ class DiskBuilder:
                         self.xml_state.build_type.get_squashfscompression()
                 }
             )
+            exclude_list = self._get_exclude_list_for_root_data_sync(device_map)
+            # To allow running custom scripts in a read-only root
+            # it's required to keep the /image mountpoint directory
+            # such that it can be bind mounted from the unpacked
+            # root tree
+            exclude_list.remove('image')
+            exclude_list.append('image/*')
             squashed_root.create_on_file(
                 filename=squashed_root_file.name,
-                exclude=self._get_exclude_list_for_root_data_sync(device_map)
+                exclude=exclude_list
+            )
+
+            if self.root_filesystem_verity_blocks:
+                squashed_root.create_verity_layer(
+                    self.root_filesystem_verity_blocks if
+                    self.root_filesystem_verity_blocks != 'all' else None
+                )
+
+            readonly_target = device_map['readonly'].get_device()
+            readonly_target_bytesize = device_map['readonly'].get_byte_size(
+                readonly_target
+            )
+            log.info(
+                '--> Dumping rootfs file({0} bytes) -> {1}({2} bytes)'.format(
+                    os.path.getsize(squashed_root_file.name),
+                    readonly_target, readonly_target_bytesize
+                )
             )
             Command.run(
                 [
                     'dd',
                     'if=%s' % squashed_root_file.name,
-                    'of=%s' % device_map['readonly'].get_device()
+                    'of=%s' % readonly_target
                 ]
             )
+            if self.root_filesystem_embed_verity_metadata:
+                squashed_root.create_verification_metadata(
+                    readonly_target
+                )
+        elif self.root_filesystem_verity_blocks:
+            root_target = device_map['root'].get_device()
+            root_target_bytesize = device_map['root'].get_byte_size(
+                root_target
+            )
+            verity_root_file_bytes = root_target_bytesize - VeritySetup(
+                device_map['root'].get_device(),
+                self.root_filesystem_verity_blocks if
+                self.root_filesystem_verity_blocks != 'all' else None
+            ).get_hash_byte_size()
+            if self.root_filesystem_embed_verity_metadata:
+                verity_root_file_bytes -= defaults.VERIFICATION_METADATA_OFFSET
+            verity_root_file = Temporary().new_file()
+            loop_provider = LoopDevice(
+                verity_root_file.name,
+                int(verity_root_file_bytes / 1048576)
+            )
+            loop_provider.create()
+            filesystem_custom_parameters = {
+                'mount_options': self.custom_root_mount_args,
+                'create_options': self.custom_root_creation_args
+            }
+            filesystem = FileSystem.new(
+                self.requested_filesystem, loop_provider,
+                self.root_dir + '/',
+                filesystem_custom_parameters
+            )
+            filesystem.create_on_device(
+                label=self.disk_setup.get_root_label(),
+                uuid=BlockID(root_target).get_uuid()
+            )
+            filesystem.sync_data(
+                self._get_exclude_list_for_root_data_sync(device_map)
+            )
+            filesystem.umount()
+            filesystem.create_verity_layer(
+                self.root_filesystem_verity_blocks if
+                self.root_filesystem_verity_blocks != 'all' else None,
+                verity_root_file.name
+            )
+            del loop_provider
+            log.info(
+                '--> Dumping rootfs file({0} bytes) -> {1}({2} bytes)'.format(
+                    os.path.getsize(verity_root_file.name),
+                    root_target, root_target_bytesize
+                )
+            )
+            Command.run(
+                [
+                    'dd',
+                    'if=%s' % verity_root_file.name,
+                    'of=%s' % root_target
+                ]
+            )
+            if self.root_filesystem_embed_verity_metadata:
+                filesystem.create_verification_metadata(
+                    root_target
+                )
         else:
             system.sync_data(
                 self._get_exclude_list_for_root_data_sync(device_map)
