@@ -35,7 +35,36 @@ from kiwi.version import (
 
 from kiwi.exceptions import KiwiBootLoaderGrubDataError
 
+shim_loader_type = NamedTuple(
+    'shim_loader_type', [
+        ('filename', str),
+        ('binaryname', str)
+    ]
+)
+
+grub_loader_type = NamedTuple(
+    'grub_loader_type', [
+        ('filename', str),
+        ('binaryname', str)
+    ]
+)
+
+unit_type = NamedTuple(
+    'unit_type', [
+        ('byte', str),
+        ('kb', str),
+        ('mb', str),
+        ('gb', str)
+    ]
+)
+
+
 # Default module variables
+VERITY_DATA_BLOCKSIZE = 4096  # 4kb
+VERITY_HASH_BLOCKSIZE = 4096  # 4kb
+VERIFICATION_METADATA_FORMAT_VERSION = '1'
+VERIFICATION_METADATA_OFFSET = 4096  # 4kb
+UNIT = unit_type(byte='b', kb='k', mb='m', gb='g')
 POST_DISK_SYNC_SCRIPT = 'disk.sh'
 PRE_DISK_SYNC_SCRIPT = 'pre_disk_sync.sh'
 POST_BOOTSTRAP_SCRIPT = 'post_bootstrap.sh'
@@ -52,20 +81,6 @@ PLATFORM_MACHINE = platform.machine()
 
 log = logging.getLogger('kiwi')
 
-shim_loader_type = NamedTuple(
-    'shim_loader_type', [
-        ('filename', str),
-        ('binaryname', str)
-    ]
-)
-
-grub_loader_type = NamedTuple(
-    'grub_loader_type', [
-        ('filename', str),
-        ('binaryname', str)
-    ]
-)
-
 
 class Defaults:
     """
