@@ -36,7 +36,8 @@ from kiwi.utils.size import StringToSize
 from kiwi.exceptions import (
     KiwiProfileNotFound,
     KiwiTypeNotFound,
-    KiwiDistributionNameError
+    KiwiDistributionNameError,
+    KiwiFileAccessError
 )
 
 log = logging.getLogger('kiwi')
@@ -2212,6 +2213,56 @@ class XMLState:
 
         return option_list
 
+    def get_luks_credentials(self) -> Optional[str]:
+        """
+        Return key or passphrase credentials to open the luks pool
+
+        :return: data
+
+        :rtype: str
+        """
+        data = self.build_type.get_luks()
+        if data:
+            keyfile_name = None
+            try:
+                # try to interpret data as an URI
+                uri = Uri(data)
+                if not uri.is_remote():
+                    keyfile_name = uri.translate()
+            except Exception:
+                # this doesn't look like a valid URI, continue as just data
+                pass
+            if keyfile_name:
+                try:
+                    with open(keyfile_name) as keyfile:
+                        return keyfile.read()
+                except Exception as issue:
+                    raise KiwiFileAccessError(
+                        f'Failed to read from {keyfile_name!r}: {issue}'
+                    )
+        return data
+
+    def get_luks_format_options(self) -> List[str]:
+        """
+        Return list of luks format options
+
+        :return: list of options
+
+        :rtype: list
+        """
+        result = []
+        luksversion = self.build_type.get_luks_version()
+        luksformat = self.build_type.get_luksformat()
+        if luksversion:
+            result.append('--type')
+            result.append(luksversion)
+        if luksformat:
+            for option in luksformat[0].get_option():
+                result.append(option.get_name())
+                if option.get_value():
+                    result.append(option.get_value())
+        return result
+
     def get_derived_from_image_uri(self) -> Optional[Uri]:
         """
         Uri object of derived image if configured
@@ -2368,15 +2419,15 @@ class XMLState:
             maintainer = container_config_section.get_maintainer()
             user = container_config_section.get_user()
             workingdir = container_config_section.get_workingdir()
-            additional_tags = container_config_section.get_additionaltags()
+            additional_names = container_config_section.get_additionalnames()
             if name:
                 container_base['container_name'] = name
 
             if tag:
                 container_base['container_tag'] = tag
 
-            if additional_tags:
-                container_base['additional_tags'] = additional_tags.split(',')
+            if additional_names:
+                container_base['additional_names'] = additional_names.split(',')
 
             if maintainer:
                 container_base['maintainer'] = maintainer
