@@ -286,9 +286,11 @@ class TestDiskBuilder:
     @patch('random.randrange')
     @patch('kiwi.builder.disk.Command.run')
     @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
+    @patch('kiwi.builder.disk.ImageSystem')
     @patch('os.path.exists')
     def test_create_disk_standard_root_with_kiwi_initrd(
-        self, mock_path, mock_grub_dir, mock_command, mock_rand, mock_fs
+        self, mock_path, mock_ImageSystem, mock_grub_dir,
+        mock_command, mock_rand, mock_fs
     ):
         mock_path.return_value = True
         mock_rand.return_value = 15
@@ -414,11 +416,20 @@ class TestDiskBuilder:
     @patch('kiwi.builder.disk.Command.run')
     @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
     @patch('os.path.exists')
+    @patch('os.path.getsize')
     @patch('kiwi.builder.disk.SystemSetup')
+    @patch('kiwi.builder.disk.ImageSystem')
+    @patch('kiwi.builder.disk.VeritySetup')
+    @patch('kiwi.builder.disk.Temporary.new_file')
     def test_create_disk_standard_root_with_dracut_initrd(
-        self, mock_SystemSetup, mock_path, mock_grub_dir,
-        mock_command, mock_rand, mock_fs
+        self, mock_Temporary_new_file, mock_VeritySetup,
+        mock_ImageSystem, mock_SystemSetup, mock_os_path_getsize,
+        mock_path, mock_grub_dir, mock_command, mock_rand, mock_fs
     ):
+        tempfile = Mock()
+        tempfile.name = 'tempfile'
+        mock_Temporary_new_file.return_value = tempfile
+        mock_os_path_getsize.return_value = 42
         self.boot_image_task.get_boot_names.return_value = self.boot_names_type(
             kernel_name='vmlinuz-1.2.3-default',
             initrd_name='initramfs-1.2.3.img'
@@ -427,6 +438,9 @@ class TestDiskBuilder:
         mock_rand.return_value = 15
         filesystem = Mock()
         mock_fs.return_value = filesystem
+        self.disk_builder.root_filesystem_verity_blocks = 10
+        self.disk_builder.root_filesystem_embed_verity_metadata = True
+        self.disk_builder.root_filesystem_is_overlay = False
         self.disk_builder.volume_manager_name = None
         self.disk_builder.initrd_system = 'dracut'
         self.setup.script_exists.return_value = True
@@ -442,7 +456,9 @@ class TestDiskBuilder:
             '/etc/selinux/targeted/contexts/files/file_contexts'
         )
         self.disk_setup.get_disksize_mbytes.assert_called_once_with()
-        self.loop_provider.create.assert_called_once_with()
+        assert self.loop_provider.create.call_args_list == [
+            call(), call()
+        ]
         self.disk.wipe.assert_called_once_with()
         self.disk.create_efi_csm_partition.assert_called_once_with(
             self.firmware.get_legacy_bios_partition_size()
@@ -480,7 +496,6 @@ class TestDiskBuilder:
             call('pre_disk_sync.sh'),
             call('disk.sh')
         ]
-        disk_system.import_description.assert_called_once_with()
         disk_system.call_pre_disk_script.assert_called_once_with()
         disk_system.call_disk_script.assert_called_once_with()
         self.setup.call_edit_boot_config_script.assert_called_once_with(
@@ -524,7 +539,9 @@ class TestDiskBuilder:
         ]
         assert mock_command.call_args_list == [
             call(['cp', 'root_dir/recovery.partition.size', 'boot_dir']),
-            call(['mv', 'initrd', 'root_dir/boot/initramfs-1.2.3.img'])
+            call(['mv', 'initrd', 'root_dir/boot/initramfs-1.2.3.img']),
+            call(['blockdev', '--getsize64', '/dev/root-device']),
+            call(['dd', 'if=tempfile', 'of=/dev/root-device'])
         ]
         self.block_operation.get_blkid.assert_has_calls(
             [call('PARTUUID')]
@@ -545,6 +562,10 @@ class TestDiskBuilder:
         self.boot_image_task.omit_module.assert_called_once_with('multipath')
         assert self.boot_image_task.write_system_config_file.call_args_list == \
             []
+        filesystem.create_verity_layer.assert_called_once_with(10, 'tempfile')
+        filesystem.create_verification_metadata.assert_called_once_with(
+            '/dev/root-device'
+        )
 
     @patch('kiwi.builder.disk.DeviceProvider')
     @patch('kiwi.builder.disk.FileSystem.new')
@@ -555,14 +576,21 @@ class TestDiskBuilder:
     @patch('os.path.getsize')
     @patch('kiwi.builder.disk.Temporary.new_file')
     @patch('random.randrange')
+    @patch('kiwi.builder.disk.BlockID')
     def test_create_disk_standard_root_is_overlay(
-        self, mock_rand, mock_temp, mock_getsize, mock_exists,
-        mock_grub_dir, mock_command, mock_squashfs, mock_fs,
-        mock_DeviceProvider
+        self, mock_BlockID, mock_rand, mock_temp,
+        mock_getsize, mock_exists, mock_grub_dir, mock_command,
+        mock_squashfs, mock_fs, mock_DeviceProvider
     ):
+        block_operation = Mock()
+        block_operation.get_blkid.return_value = 'partuuid'
+        block_operation.get_filesystem.return_value = 'ext3'
+        mock_BlockID.return_value = block_operation
         mock_rand.return_value = 15
         self.disk_builder.root_filesystem_is_overlay = True
         self.disk_builder.root_filesystem_has_write_partition = False
+        self.disk_builder.root_filesystem_verity_blocks = 10
+        self.disk_builder.root_filesystem_embed_verity_metadata = True
         self.disk_builder.volume_manager_name = None
         squashfs = Mock()
         mock_squashfs.return_value = squashfs
@@ -574,7 +602,6 @@ class TestDiskBuilder:
         self.disk_builder.initrd_system = 'dracut'
         self.disk.public_partition_id_map = self.id_map
         self.disk.public_partition_id_map['kiwi_ROPart'] = 1
-
         m_open = mock_open()
         with patch('builtins.open', m_open, create=True):
             self.disk_builder.create_disk()
@@ -593,20 +620,31 @@ class TestDiskBuilder:
         assert squashfs.create_on_file.call_args_list == [
             call(exclude=['var/cache/kiwi'], filename='kiwi-tempname'),
             call(exclude=[
-                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                '.profile', '.kconfig', 'run/*', 'tmp/*',
                 '.buildenv', 'var/cache/kiwi',
-                'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
+                'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*', 'image/*'
             ], filename='kiwi-tempname')
         ]
+        squashfs.create_verity_layer.assert_called_once_with(10)
+        squashfs.create_verification_metadata.assert_called_once_with(
+            '/dev/readonly-root-device'
+        )
         self.disk.create_root_readonly_partition.assert_called_once_with(11)
         assert mock_command.call_args_list[2] == call(
+            ['blockdev', '--getsize64', '/dev/readonly-root-device']
+        )
+        assert mock_command.call_args_list[3] == call(
             ['dd', 'if=kiwi-tempname', 'of=/dev/readonly-root-device']
         )
         assert m_open.return_value.write.call_args_list == [
+            # config.partids
             call('kiwi_BootPart="1"\n'),
             call('kiwi_RootPart="1"\n'),
+            # mbrid
             call('0x0f0f0f0f\n'),
+            # config.bootoptions
             call('boot_cmdline\n'),
+            # some-loop
             call(b'\x0f\x0f\x0f\x0f')
         ]
         assert self.boot_image_task.include_module.call_args_list == [
@@ -738,7 +776,8 @@ class TestDiskBuilder:
             self.disk_builder.create_disk()
 
         self.luks_root.create_crypto_luks.assert_called_once_with(
-            passphrase='passphrase', os=None, keyfile='root_dir/.root.keyfile'
+            passphrase='passphrase', os=None,
+            options=[], keyfile='root_dir/.root.keyfile'
         )
         self.luks_root.create_crypttab.assert_called_once_with(
             'root_dir/etc/crypttab'
@@ -777,21 +816,36 @@ class TestDiskBuilder:
         with patch('builtins.open'):
             self.disk_builder.create_disk()
 
+        self.disk.persistency_type = 'by-uuid'
         self.disk.create_custom_partitions.assert_called_once_with(
             self.disk_builder.custom_partitions
         )
-
         assert [
             call('UUID=blkid_result /var blkid_result_fs defaults 0 0')
         ] in self.disk_builder.fstab.add_entry.call_args_list
 
+        self.disk_builder.persistency_type = 'by-partuuid'
+        with patch('builtins.open'):
+            self.disk_builder.create_disk()
+        assert [
+            call('PARTUUID=blkid_result /var blkid_result_fs defaults 0 0')
+        ] in self.disk_builder.fstab.add_entry.call_args_list
+
+        self.disk_builder.persistency_type = 'by-label'
+        with patch('builtins.open'):
+            self.disk_builder.create_disk()
+        assert [
+            call('LABEL=blkid_result /var blkid_result_fs defaults 0 0')
+        ] in self.disk_builder.fstab.add_entry.call_args_list
+
     @patch('kiwi.builder.disk.FileSystem.new')
     @patch('kiwi.builder.disk.VolumeManager.new')
     @patch('kiwi.builder.disk.Command.run')
     @patch('kiwi.builder.disk.Defaults.get_grub_boot_directory_name')
+    @patch('kiwi.builder.disk.ImageSystem')
     @patch('os.path.exists')
     def test_create_disk_volume_managed_root(
-        self, mock_exists, mock_grub_dir, mock_command,
+        self, mock_exists, mock_ImageSystem, mock_grub_dir, mock_command,
         mock_volume_manager, mock_fs
     ):
         mock_exists.return_value = True
