@@ -24,7 +24,7 @@ class TestFileSystemExt2:
 
     @patch('kiwi.filesystem.ext2.Command.run')
     def test_create_on_device(self, mock_command):
-        self.ext2.create_on_device('label')
+        self.ext2.create_on_device('label', 100, uuid='uuid')
         call = mock_command.call_args_list[0]
         assert mock_command.call_args_list[0] == \
-            call(['mkfs.ext2', '-L', 'label', '/dev/foo'])
+            call(['mkfs.ext2', '-L', 'label', '-U', 'uuid', '/dev/foo', '100'])
