@@ -24,7 +24,7 @@ class TestFileSystemExt3:
 
     @patch('kiwi.filesystem.ext3.Command.run')
     def test_create_on_device(self, mock_command):
-        self.ext3.create_on_device('label')
+        self.ext3.create_on_device('label', 100, uuid='uuid')
         call = mock_command.call_args_list[0]
         assert mock_command.call_args_list[0] == \
-            call(['mkfs.ext3', '-L', 'label', '/dev/foo'])
+            call(['mkfs.ext3', '-L', 'label', '-U', 'uuid', '/dev/foo', '100'])
