@@ -34,6 +34,9 @@ class TestDiskFormatVhdFixed:
             self.xml_state, 'root_dir', 'target_dir', {'force_size': None}
         )
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_post_init(self):
         self.disk_format.post_init({'option': 'value', '--tag': 'tag'})
         assert self.disk_format.options == [
