@@ -30,10 +30,7 @@ class TestSystemPrepare:
     @patch('kiwi.system.prepare.RootInit')
     @patch('kiwi.system.prepare.RootBind')
     @patch('kiwi.logger.Logger.get_logfile')
-    def setup(
-        self, mock_SystemPrepare, mock_get_logfile,
-        mock_root_bind, mock_root_init
-    ):
+    def setup(self, mock_get_logfile, mock_root_bind, mock_root_init):
         Defaults.set_platform_name('x86_64')
         mock_get_logfile.return_value = None
         description = XMLDescription(
@@ -72,6 +69,12 @@ class TestSystemPrepare:
         root_bind.setup_intermediate_config.assert_called_once_with()
         root_bind.mount_kernel_file_systems.assert_called_once_with()
 
+    @patch('kiwi.system.prepare.RootInit')
+    @patch('kiwi.system.prepare.RootBind')
+    @patch('kiwi.logger.Logger.get_logfile')
+    def setup_method(self, cls, mock_get_logfile, mock_root_bind, mock_root_init):
+        self.setup()
+
     @patch('kiwi.system.prepare.RootImport.new')
     @patch('kiwi.system.prepare.RootInit')
     @patch('kiwi.system.prepare.RootBind')
@@ -123,12 +126,13 @@ class TestSystemPrepare:
 
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
     def test_install_bootstrap_packages_raises(self, mock_poll):
+        self.manager.get_error_details.return_value = 'error-details'
         mock_poll.side_effect = Exception('some_error')
         with raises(KiwiBootStrapPhaseFailed) as issue:
             self.system.install_bootstrap(self.manager)
         assert issue.value.message == self.system.issue_message.format(
             headline='Bootstrap package installation failed',
-            reason='some_error'
+            reason='some_error: error-details'
         )
 
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
